@@ -1,9 +1,9 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Not, Equal, Eval
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 
 class Purchase(ModelSQL, ModelView):
@@ -16,25 +16,24 @@ class Purchase(ModelSQL, ModelView):
                     'on line "%s" (%d)!',
             })
 
-    def check_for_quotation(self, purchase_id):
-        account_selection_obj = self.pool.get(
+    def check_for_quotation(self, ids):
+        account_selection_obj = Pool().get(
                 'analytic_account.account.selection')
-        purchase_line_obj = self.pool.get('purchase.line')
 
-        res = super(Purchase, self).check_for_quotation(purchase_id)
+        super(Purchase, self).check_for_quotation(ids)
 
-        purchase = self.browse(purchase_id)
-        if not account_selection_obj.check_root(
-                [x.analytic_accounts.id for x in purchase.lines
-                    if x.analytic_accounts.id]):
-            for line in purchase.lines:
-                if line.type != 'line':
-                    continue
-                if not account_selection_obj.check_root(
-                        [line.analytic_accounts.id]):
-                    self.raise_user_error('analytic_account_required',
-                            (line.rec_name, line.id))
-        return res
+        purchases = self.browse(ids)
+        for purchase in purchases:
+            if not account_selection_obj.check_root(
+                    [x.analytic_accounts.id for x in purchase.lines
+                        if x.analytic_accounts.id]):
+                for line in purchase.lines:
+                    if line.type != 'line':
+                        continue
+                    if not account_selection_obj.check_root(
+                            [line.analytic_accounts.id]):
+                        self.raise_user_error('analytic_account_required',
+                                (line.rec_name, line.id))
 
 Purchase()
 
@@ -43,20 +42,20 @@ class PurchaseLine(ModelSQL, ModelView):
     _name = 'purchase.line'
 
     analytic_accounts = fields.Many2One('analytic_account.account.selection',
-            'Analytic Accounts',
-            states={
-                'invisible': Not(Equal(Eval('type'), 'line')),
-            })
+        'Analytic Accounts',
+        states={
+            'invisible': Eval('type') != 'line',
+            }, depends=['type'])
 
     def _view_look_dom_arch(self, tree, type, field_children=None):
-        analytic_account_obj = self.pool.get('analytic_account.account')
+        analytic_account_obj = Pool().get('analytic_account.account')
         analytic_account_obj.convert_view(tree)
-        arch, fields = super(PurchaseLine, self)._view_look_dom_arch(tree, type,
-            field_children=field_children)
+        arch, fields = super(PurchaseLine, self)._view_look_dom_arch(tree,
+            type, field_children=field_children)
         return arch, fields
 
     def fields_get(self, fields_names=None):
-        analytic_account_obj = self.pool.get('analytic_account.account')
+        analytic_account_obj = Pool().get('analytic_account.account')
 
         res = super(PurchaseLine, self).fields_get(fields_names)
 
@@ -73,8 +72,6 @@ class PurchaseLine(ModelSQL, ModelView):
             with_rec_name=with_rec_name)
 
     def read(self, ids, fields_names=None):
-        selection_obj = self.pool.get('analytic_account.account.selection')
-
         int_id = False
         if isinstance(ids, (int, long)):
             int_id = True
@@ -104,7 +101,7 @@ class PurchaseLine(ModelSQL, ModelView):
             for line in lines:
                 for root_id in root_ids:
                     id2record[line.id]['analytic_account_' \
-                            + str(root_id)] = False
+                            + str(root_id)] = None
                 if line.type != 'line':
                     continue
                 if not line.analytic_accounts:
@@ -123,7 +120,7 @@ class PurchaseLine(ModelSQL, ModelView):
         return res
 
     def create(self, vals):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
         vals = vals.copy()
         selection_vals = {}
         for field in vals.keys():
@@ -140,7 +137,7 @@ class PurchaseLine(ModelSQL, ModelView):
         return super(PurchaseLine, self).create(vals)
 
     def write(self, ids, vals):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
         vals = vals.copy()
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -181,7 +178,7 @@ class PurchaseLine(ModelSQL, ModelView):
         return super(PurchaseLine, self).write(ids, vals)
 
     def delete(self, ids):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -196,7 +193,7 @@ class PurchaseLine(ModelSQL, ModelView):
         return res
 
     def copy(self, ids, default=None):
-        selection_obj = self.pool.get('analytic_account.account.selection')
+        selection_obj = Pool().get('analytic_account.account.selection')
 
         new_ids = super(PurchaseLine, self).copy(ids, default=default)
 
@@ -217,7 +214,8 @@ class PurchaseLine(ModelSQL, ModelView):
         return new_ids
 
     def get_invoice_line(self, line):
-        account_selection_obj = self.pool.get('analytic_account.account.selection')
+        pool = Pool()
+        account_selection_obj = pool.get('analytic_account.account.selection')
 
         res = super(PurchaseLine, self).get_invoice_line(line)
         if not res:
@@ -225,7 +223,8 @@ class PurchaseLine(ModelSQL, ModelView):
 
         selection_id = False
         if line.analytic_accounts:
-            selection_id = account_selection_obj.copy(line.analytic_accounts.id)
+            selection_id = account_selection_obj.copy(
+                line.analytic_accounts.id)
         for vals in res:
             vals['analytic_accounts'] = selection_id
         return res
@@ -237,21 +236,21 @@ class Account(ModelSQL, ModelView):
     _name = 'analytic_account.account'
 
     def delete(self, ids):
-        purchase_line_obj = self.pool.get('purchase.line')
+        purchase_line_obj = Pool().get('purchase.line')
         res = super(Account, self).delete(ids)
         # Restart the cache on the fields_view_get method of purchase.line
         purchase_line_obj.fields_view_get.reset()
         return res
 
     def create(self, vals):
-        purchase_line_obj = self.pool.get('purchase.line')
+        purchase_line_obj = Pool().get('purchase.line')
         res = super(Account, self).create(vals)
         # Restart the cache on the fields_view_get method of purchase.line
         purchase_line_obj.fields_view_get.reset()
         return res
 
     def write(self, ids, vals):
-        purchase_line_obj = self.pool.get('purchase.line')
+        purchase_line_obj = Pool().get('purchase.line')
         res = super(Account, self).write(ids, vals)
         # Restart the cache on the fields_view_get method of purchase.line
         purchase_line_obj.fields_view_get.reset()
